@@ -7,6 +7,7 @@ use atelier_core::builder::{
 use atelier_core::model::Model;
 use atelier_core::Version;
 use pretty_assertions::assert_eq;
+use std::convert::TryInto;
 
 fn make_model() -> Model {
     ModelBuilder::new(Version::V10, "smithy.example")
@@ -24,15 +25,16 @@ fn make_model() -> Model {
         )
         .simple_shape(SimpleShapeBuilder::string("MyString"))
         .simple_shape(SimpleShapeBuilder::boolean("MyBoolean"))
-        .into()
+        .try_into()
+        .unwrap()
 }
 
 #[test]
 fn test_correct_type_references() {
     let expected = [
+        "Structure member\'s type (foo.baz#MyString) cannot be resolved to a shape in this model.",
         "The simple shape (smithy.example#MyString) is simply a synonym, did you mean to add any constraint traits?",
         "The simple shape (smithy.example#MyBoolean) is simply a synonym, did you mean to add any constraint traits?",
-        "Structure member\'s type (foo.baz#MyString) cannot be resolved to a shape in this model.",
     ];
     let model: Model = make_model();
     let result = run_validation_actions(
@@ -61,7 +63,8 @@ fn test_unresolved_references() {
     let model: Model = ModelBuilder::new(Version::V10, "smithy.example")
         .uses("foo.baz#Bar")
         .simple_shape(SimpleShapeBuilder::boolean("MyBoolean"))
-        .into();
+        .try_into()
+        .unwrap();
     let result = run_validation_actions(
         &mut [Box::new(NoUnresolvedReferences::default())],
         &model,
